timeintervaltools.calculate_density_of_attacks_in_interval
==========================================================

.. autofunction:: abjad.tools.timeintervaltools.calculate_density_of_attacks_in_interval.calculate_density_of_attacks_in_interval
